==> img0ch-2.1.17.tar.bz2: img0ch/_template/default/search_image.cs <==
<html>
<head>
<title>img0ch - 摜</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/jquery-1.1.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch/app.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
jQuery(function(){
    jQuery("//input[@name='word']").get(0).focus();
});
function redir(element) {
    app.redirectRenderer(element);
    return true;
}
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
<?cs var:TagCloudCSS ?>
-->
</style>
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><?cs var:Banner ?></table><hr><?cs /if ?>

<table border="1" align="center" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
<tr><td>
<form action="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi" method="post">
<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi/<?cs var:html_escape(BBS) ?>/">tH[</a>
<br>
<center>
<input type="text" name="word" value="" size="70"><br>
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="submit" value="̃^OŌ">
</center>
</form>
</td></tr>
<tr><td>
u<?cs var:html_escape(BBS_TITLE) ?>ṽ^Oꗗ<br>
<?cs var:TagCloudHTML ?>
</td></tr>
<tr><td><div id="footer"><a href="http://img0ch.sourceforge.jp">img0ch-sf.cgi - img0ch BBS</a></div></td></tr>
</table>

<?cs if:Total ?>
<hr>
<table border="1" align="center" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
<tr><td>
u<?cs var:html_escape(Word) ?>v̌ʁF<?cs var:html_escape(Total) ?><br>
<?cs if:Prev ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&word=<?cs var:html_escape(WordURLEscaped) ?>&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(Prev) ?>">&lt;&lt;O</a><?cs /if ?>
<?cs each:item = Pages ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&word=<?cs var:html_escape(WordURLEscaped) ?>&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(item.num) ?>">[<?cs var:html_escape(item.num) ?>]</a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&word=<?cs var:html_escape(WordURLEscaped) ?>&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(Next) ?>">&gt;&gt;</a><?cs /if ?>
</td></tr>
</table><hr>
<table border="1" align="center" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
<thead><tr><td>摜܂̓t@CURL</td><td>Xbh̃TuWFNg</td><td>t@C̃nbV</td></tr></thead>
<tbody><?cs each:item = Result ?><tr><td><?cs if:item.thumbpath ?><a href="<?cs var:html_escape(item.url) ?>"><img class="image" src="<?cs var:html_escape(item.thumbpath) ?>" width="<?cs var:html_escape(item.width2) ?>" height="<?cs var:html_escape(item.height2) ?>" alt="<?cs var:html_escape(item.resno) ?>.<?cs var:html_escape(item.extension) ?> (<?cs var:html_escape(item.width) ?>x<?cs var:html_escape(item.height) ?>)"></a><?cs else ?><a href="<?cs var:html_escape(item.url) ?>"><?cs var:html_escape(item.resno) ?>.<?cs var:html_escape(item.extension) ?></a><?cs /if ?></td><td><a href="<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:item.resno ?>" onclick="redir(this)"><?cs var:item.subject ?></a><br>(<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:item.resno ?>">t@CǗ</a>)</td><td><?cs var:item.hash ?></td></tr>
<?cs /each ?>
</tbody>
</table>
<?cs /if ?>

</body>
</html>

==> img0ch-3.0.1.tar.bz2: img0ch/_template/default/search_image.cs <==
<html>
<head>
<title>img0ch - 摜</title>
<meta http-equiv="Content-Type" content="text/html; charset=Shift_JIS">
<meta http-equiv="Content-Script-Type" content="text/javascript">
<meta http-equiv="Content-Style-Type" content="text/css">
<meta name="VERSION" content="<?cs var:html_escape(VERSION) ?>">
<script src="<?cs var:html_escape(StaticURI) ?>/js/img0ch.js" charset="UTF-8"></script>
<script type="text/javascript">
//<!--
var app = Img0ch.App;
app.setBBS("<?cs var:html_escape(BBS) ?>");
app.setBBSURI("<?cs var:html_escape(BBSURI) ?>");
app.setCGIURI("<?cs var:html_escape(CGIURI) ?>");
app.setStaticURI("<?cs var:html_escape(StaticURI) ?>");
jQuery(function(){
    jQuery("//input[@name='word']").get(0).focus();
});
function redir(element) {
    app.redirectRenderer(element);
    return true;
}
//-->
</script>
<style type="text/css">
<!--
.clear { clear: both; }
.icon-align { vertical-align: top; }
.image { border: none; float: left; }
<?cs var:TagCloudCSS ?>
-->
</style>
<?cs var:META ?>
</head>

<body bgcolor="<?cs var:html_escape(BBS_BG_COLOR) ?>" text="<?cs var:html_escape(BBS_TEXT_COLOR) ?>" link="<?cs var:html_escape(BBS_LINK_COLOR) ?>" alink="<?cs var:html_escape(BBS_ALINK_COLOR) ?>" vlink="<?cs var:html_escape(BBS_VLINK_COLOR) ?>" background="<?cs var:html_escape(BBS_BG_PICTURE) ?>">
<?cs if:Banner ?><table border="1" cellspacing="7" cellpadding="3" width="100%" bgcolor="#ccffcc" align="center"><tr><td><?cs var:Banner ?></td></tr></table><hr><?cs /if ?>

<table border="1" align="center" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
<tr><td>
<form action="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi" method="post">
<a href="<?cs var:html_escape(BBSURI) ?>/">fɖ߂</a>
<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-sf.cgi/<?cs var:html_escape(BBS) ?>/">tH[</a>
<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/">fS</a>
<br>
<center>
<input type="text" name="word" value="" size="70"><br>
<input type="hidden" name="bbs" value="<?cs var:html_escape(BBS) ?>">
<input type="submit" value="̃^OŌ">
</center>
</form>
</td></tr>
<tr><td>
u<?cs var:html_escape(BBS_TITLE) ?>ṽ^Oꗗ<br>
<?cs var:TagCloudHTML ?>
</td></tr>
<tr><td><div id="footer"><a href="http://img0ch.sourceforge.jp">img0ch-sf.cgi - img0ch BBS</a></div></td></tr>
</table>

<?cs if:Total ?>
<hr>
<table border="1" align="center" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
<tr><td>
u<?cs var:html_escape(Word) ?>v̌ʁF<?cs var:html_escape(Total) ?><br>
<?cs if:Prev ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&word=<?cs var:html_escape(WordURLEscaped) ?>&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(Prev) ?>">&lt;&lt;O</a><?cs /if ?>
<?cs each:item = Pages ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&word=<?cs var:html_escape(WordURLEscaped) ?>&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(item.num) ?>">[<?cs var:html_escape(item.num) ?>]</a>
<?cs /each ?>
<?cs if:Next ?><a href="<?cs var:CGIURI ?>/img0ch-sf.cgi?bbs=<?cs var:html_escape(BBS) ?>&word=<?cs var:html_escape(WordURLEscaped) ?>&entries=<?cs var:html_escape(Item) ?>&offset=<?cs var:html_escape(Next) ?>">&gt;&gt;</a><?cs /if ?>
</td></tr>
</table><hr>
<table border="1" align="center" cellspacing="7" cellpadding="3" width="95%" bgcolor="<?cs var:html_escape(BBS_MENU_COLOR) ?>">
<thead><tr><td>摜܂̓t@CURL</td><td>Xbh̃TuWFNg</td><td>t@C̃nbV</td></tr></thead>
<tbody><?cs each:item = Result ?><tr><td><?cs if:item.thumbpath ?><a href="<?cs var:html_escape(item.url) ?>"><img class="image" src="<?cs var:html_escape(item.thumbpath) ?>" width="<?cs var:html_escape(item.width2) ?>" height="<?cs var:html_escape(item.height2) ?>" alt="<?cs var:html_escape(item.resno) ?>.<?cs var:html_escape(item.extension) ?> (<?cs var:html_escape(item.width) ?>x<?cs var:html_escape(item.height) ?>)"></a><?cs else ?><a href="<?cs var:html_escape(item.url) ?>"><?cs var:html_escape(item.resno) ?>.<?cs var:html_escape(item.extension) ?></a><?cs /if ?></td><td><a href="<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:item.resno ?>" onclick="redir(this)"><?cs var:html_escape(item.subject) ?></a><br>(<a href="<?cs var:html_escape(CGIURI) ?>/img0ch-ufm.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:item.resno ?>">t@CǗ</a>)</td><td><?cs var:item.hash ?></td></tr>
<?cs /each ?>
</tbody>
</table>
<?cs /if ?>

</body>
</html>
